# aws-key-formatter

Project/Repo:

[![MIT License][license_img]][license_ref]
[![Supported Python Versions][pyversions_img]][pyversions_ref]
[![aws-key-formatter v0.0.4][version_img]][version_ref]
[![PyPI Releases][pypi_img]][pypi_ref]
[![PyPI Downloads][downloads_img]][downloads_ref]

Code Quality/CI:

[![Build Status][travis_img]][travis_ref]

<!-- References -->

[downloads_img]: https://pepy.tech/badge/aws-key-formatter/month
[downloads_ref]: https://pepy.tech/project/aws-key-formatter

[license_img]: https://img.shields.io/badge/License-MIT-blue.svg
[license_ref]: https://github.com/KeltonKarboviak/aws-key-formatter/blob/master/LICENSE.md

[pypi_img]: https://img.shields.io/badge/PyPI-wheels-green.svg
[pypi_ref]: https://pypi.org/project/aws-key-formatter/#files

[pyversions_img]: https://img.shields.io/pypi/pyversions/aws-key-formatter.svg
[pyversions_ref]: https://pypi.org/pypi/aws-key-formatter

[travis_img]: https://travis-ci.org/KeltonKarboviak/aws-key-formatter.svg?branch=master
[travis_ref]: https://travis-ci.org/KeltonKarboviak/aws-key-formatter

[version_img]: https://img.shields.io/static/v1.svg?label=aws-key-formatter&message=v0.0.5&color=blue
[version_ref]: https://pypi.org/project/aws-key-formatter/
